# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        CohortResponse,
        Lang2FhirAndCreateMultiResponse,
        Lang2FhirAndCreateMultiResponseResourceInfoItem,
        Lang2FhirAndCreateMultiResponseResponseBundle,
        Lang2FhirAndCreateRequestResource,
        Lang2FhirAndCreateResponse,
        Lang2FhirAndSearchResponse,
        McpServerResponse,
        McpServerResponseData,
        McpServerToolCallResponse,
        McpServerToolResponse,
        McpServerToolResponseData,
        SearchConcept,
    )
    from .errors import BadRequestError, FailedDependencyError, ForbiddenError, InternalServerError, UnauthorizedError
    from . import mcp_server
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestError": ".errors",
    "CohortResponse": ".types",
    "FailedDependencyError": ".errors",
    "ForbiddenError": ".errors",
    "InternalServerError": ".errors",
    "Lang2FhirAndCreateMultiResponse": ".types",
    "Lang2FhirAndCreateMultiResponseResourceInfoItem": ".types",
    "Lang2FhirAndCreateMultiResponseResponseBundle": ".types",
    "Lang2FhirAndCreateRequestResource": ".types",
    "Lang2FhirAndCreateResponse": ".types",
    "Lang2FhirAndSearchResponse": ".types",
    "McpServerResponse": ".types",
    "McpServerResponseData": ".types",
    "McpServerToolCallResponse": ".types",
    "McpServerToolResponse": ".types",
    "McpServerToolResponseData": ".types",
    "SearchConcept": ".types",
    "UnauthorizedError": ".errors",
    "mcp_server": ".mcp_server",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestError",
    "CohortResponse",
    "FailedDependencyError",
    "ForbiddenError",
    "InternalServerError",
    "Lang2FhirAndCreateMultiResponse",
    "Lang2FhirAndCreateMultiResponseResourceInfoItem",
    "Lang2FhirAndCreateMultiResponseResponseBundle",
    "Lang2FhirAndCreateRequestResource",
    "Lang2FhirAndCreateResponse",
    "Lang2FhirAndSearchResponse",
    "McpServerResponse",
    "McpServerResponseData",
    "McpServerToolCallResponse",
    "McpServerToolResponse",
    "McpServerToolResponseData",
    "SearchConcept",
    "UnauthorizedError",
    "mcp_server",
]
