# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ErrorResponse,
        FhirBundle,
        FhirBundleEntryItem,
        FhirBundleEntryItemRequest,
        FhirBundleEntryItemRequestMethod,
        FhirBundleEntryItemResponse,
        FhirPatchRequestBodyItem,
        FhirPatchRequestBodyItemOp,
        FhirResource,
        FhirResourceMeta,
        FhirSearchResponse,
    )
    from .errors import (
        BadGatewayError,
        BadRequestError,
        InternalServerError,
        NotFoundError,
        ServiceUnavailableError,
        TooManyRequestsError,
        UnauthorizedError,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BadGatewayError": ".errors",
    "BadRequestError": ".errors",
    "ErrorResponse": ".types",
    "FhirBundle": ".types",
    "FhirBundleEntryItem": ".types",
    "FhirBundleEntryItemRequest": ".types",
    "FhirBundleEntryItemRequestMethod": ".types",
    "FhirBundleEntryItemResponse": ".types",
    "FhirPatchRequestBodyItem": ".types",
    "FhirPatchRequestBodyItemOp": ".types",
    "FhirResource": ".types",
    "FhirResourceMeta": ".types",
    "FhirSearchResponse": ".types",
    "InternalServerError": ".errors",
    "NotFoundError": ".errors",
    "ServiceUnavailableError": ".errors",
    "TooManyRequestsError": ".errors",
    "UnauthorizedError": ".errors",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadGatewayError",
    "BadRequestError",
    "ErrorResponse",
    "FhirBundle",
    "FhirBundleEntryItem",
    "FhirBundleEntryItemRequest",
    "FhirBundleEntryItemRequestMethod",
    "FhirBundleEntryItemResponse",
    "FhirPatchRequestBodyItem",
    "FhirPatchRequestBodyItemOp",
    "FhirResource",
    "FhirResourceMeta",
    "FhirSearchResponse",
    "InternalServerError",
    "NotFoundError",
    "ServiceUnavailableError",
    "TooManyRequestsError",
    "UnauthorizedError",
]
