# This file was auto-generated by Fern from our API Definition.

import typing

AgentChatStreamEventType = typing.Union[
    typing.Literal["message_start", "content_delta", "tool_use", "tool_result", "message_end", "error"], typing.Any
]
