# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        CreateMultiResponse,
        CreateMultiResponseBundle,
        CreateMultiResponseBundleEntryItem,
        CreateMultiResponseBundleEntryItemRequest,
        CreateMultiResponseResourcesItem,
        CreateRequestResource,
        FhirResource,
        Lang2FhirUploadProfileResponse,
        SearchResponse,
        SearchResponseResourceType,
    )
    from .errors import (
        BadRequestError,
        FailedDependencyError,
        ForbiddenError,
        InternalServerError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestError": ".errors",
    "CreateMultiResponse": ".types",
    "CreateMultiResponseBundle": ".types",
    "CreateMultiResponseBundleEntryItem": ".types",
    "CreateMultiResponseBundleEntryItemRequest": ".types",
    "CreateMultiResponseResourcesItem": ".types",
    "CreateRequestResource": ".types",
    "FailedDependencyError": ".errors",
    "FhirResource": ".types",
    "ForbiddenError": ".errors",
    "InternalServerError": ".errors",
    "Lang2FhirUploadProfileResponse": ".types",
    "SearchResponse": ".types",
    "SearchResponseResourceType": ".types",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestError",
    "CreateMultiResponse",
    "CreateMultiResponseBundle",
    "CreateMultiResponseBundleEntryItem",
    "CreateMultiResponseBundleEntryItemRequest",
    "CreateMultiResponseResourcesItem",
    "CreateRequestResource",
    "FailedDependencyError",
    "FhirResource",
    "ForbiddenError",
    "InternalServerError",
    "Lang2FhirUploadProfileResponse",
    "SearchResponse",
    "SearchResponseResourceType",
    "UnauthorizedError",
    "UnprocessableEntityError",
]
