# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class CreateMultiResponseResourcesItem(UniversalBaseModel):
    temp_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="tempId"),
        pydantic.Field(alias="tempId", description="Temporary UUID for the resource"),
    ] = None
    resource_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="resourceType"),
        pydantic.Field(alias="resourceType", description="FHIR resource type"),
    ] = None
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text excerpt this resource was extracted from
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
