# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        CreateWorkflowRequestFhirProviderId,
        CreateWorkflowResponse,
        DecisionNodeDefinition,
        ExecuteWorkflowResponse,
        ExecuteWorkflowResponseResults,
        Lang2FhirCreateDefinition,
        Lang2FhirSearchDefinition,
        ListWorkflowsResponse,
        StepOperation,
        SubWorkflowDefinition,
        UpdateWorkflowRequestFhirProviderId,
        WorkflowConfig,
        WorkflowDefinition,
        WorkflowGraph,
        WorkflowResponse,
        WorkflowResponseGraph,
        WorkflowStep,
        WorkflowStepSummary,
        WorkflowStepSummaryType,
        WorkflowStepType,
        WorkflowsDeleteResponse,
        WorkflowsGetResponse,
        WorkflowsUpdateResponse,
    )
    from .errors import BadRequestError, ForbiddenError, InternalServerError, NotFoundError, UnauthorizedError
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestError": ".errors",
    "CreateWorkflowRequestFhirProviderId": ".types",
    "CreateWorkflowResponse": ".types",
    "DecisionNodeDefinition": ".types",
    "ExecuteWorkflowResponse": ".types",
    "ExecuteWorkflowResponseResults": ".types",
    "ForbiddenError": ".errors",
    "InternalServerError": ".errors",
    "Lang2FhirCreateDefinition": ".types",
    "Lang2FhirSearchDefinition": ".types",
    "ListWorkflowsResponse": ".types",
    "NotFoundError": ".errors",
    "StepOperation": ".types",
    "SubWorkflowDefinition": ".types",
    "UnauthorizedError": ".errors",
    "UpdateWorkflowRequestFhirProviderId": ".types",
    "WorkflowConfig": ".types",
    "WorkflowDefinition": ".types",
    "WorkflowGraph": ".types",
    "WorkflowResponse": ".types",
    "WorkflowResponseGraph": ".types",
    "WorkflowStep": ".types",
    "WorkflowStepSummary": ".types",
    "WorkflowStepSummaryType": ".types",
    "WorkflowStepType": ".types",
    "WorkflowsDeleteResponse": ".types",
    "WorkflowsGetResponse": ".types",
    "WorkflowsUpdateResponse": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestError",
    "CreateWorkflowRequestFhirProviderId",
    "CreateWorkflowResponse",
    "DecisionNodeDefinition",
    "ExecuteWorkflowResponse",
    "ExecuteWorkflowResponseResults",
    "ForbiddenError",
    "InternalServerError",
    "Lang2FhirCreateDefinition",
    "Lang2FhirSearchDefinition",
    "ListWorkflowsResponse",
    "NotFoundError",
    "StepOperation",
    "SubWorkflowDefinition",
    "UnauthorizedError",
    "UpdateWorkflowRequestFhirProviderId",
    "WorkflowConfig",
    "WorkflowDefinition",
    "WorkflowGraph",
    "WorkflowResponse",
    "WorkflowResponseGraph",
    "WorkflowStep",
    "WorkflowStepSummary",
    "WorkflowStepSummaryType",
    "WorkflowStepType",
    "WorkflowsDeleteResponse",
    "WorkflowsGetResponse",
    "WorkflowsUpdateResponse",
]
