# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CodeSystemDetails(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Code system name
    """

    version: str = pydantic.Field()
    """
    Code system version
    """

    code_count: int = pydantic.Field()
    """
    Total number of codes in the system
    """

    builtin: bool = pydantic.Field()
    """
    Whether this is a built-in system (vs custom uploaded)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
