# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import agent, authtoken, cohort, construe, fhir, fhir_provider, lang2fhir, summary, tools, workflows
    from .client import AsyncPhenomlClient, PhenomlClient
    from .environment import PhenomlClientEnvironment
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AsyncPhenomlClient": ".client",
    "PhenomlClient": ".client",
    "PhenomlClientEnvironment": ".environment",
    "__version__": ".version",
    "agent": ".agent",
    "authtoken": ".authtoken",
    "cohort": ".cohort",
    "construe": ".construe",
    "fhir": ".fhir",
    "fhir_provider": ".fhir_provider",
    "lang2fhir": ".lang2fhir",
    "summary": ".summary",
    "tools": ".tools",
    "workflows": ".workflows",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AsyncPhenomlClient",
    "PhenomlClient",
    "PhenomlClientEnvironment",
    "__version__",
    "agent",
    "authtoken",
    "cohort",
    "construe",
    "fhir",
    "fhir_provider",
    "lang2fhir",
    "summary",
    "tools",
    "workflows",
]
