# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AgentChatResponse,
        AgentChatStreamEvent,
        AgentChatStreamEventType,
        AgentCreateRequest,
        AgentCreateRequestProvider,
        AgentDeleteResponse,
        AgentGetChatMessagesRequestOrder,
        AgentGetChatMessagesRequestRole,
        AgentGetChatMessagesResponse,
        AgentListResponse,
        AgentPromptsResponse,
        AgentResponse,
        AgentTemplate,
        AgentTemplateProvider,
        ChatMessageTemplate,
        ChatMessageTemplateRole,
        ChatSessionTemplate,
        JsonPatch,
        JsonPatchOperation,
        JsonPatchOperationOp,
        PromptTemplate,
        SuccessResponse,
    )
    from .errors import BadRequestError, ForbiddenError, InternalServerError, NotFoundError, UnauthorizedError
    from . import prompts
    from .prompts import PromptsDeleteResponse, PromptsListResponse
_dynamic_imports: typing.Dict[str, str] = {
    "AgentChatResponse": ".types",
    "AgentChatStreamEvent": ".types",
    "AgentChatStreamEventType": ".types",
    "AgentCreateRequest": ".types",
    "AgentCreateRequestProvider": ".types",
    "AgentDeleteResponse": ".types",
    "AgentGetChatMessagesRequestOrder": ".types",
    "AgentGetChatMessagesRequestRole": ".types",
    "AgentGetChatMessagesResponse": ".types",
    "AgentListResponse": ".types",
    "AgentPromptsResponse": ".types",
    "AgentResponse": ".types",
    "AgentTemplate": ".types",
    "AgentTemplateProvider": ".types",
    "BadRequestError": ".errors",
    "ChatMessageTemplate": ".types",
    "ChatMessageTemplateRole": ".types",
    "ChatSessionTemplate": ".types",
    "ForbiddenError": ".errors",
    "InternalServerError": ".errors",
    "JsonPatch": ".types",
    "JsonPatchOperation": ".types",
    "JsonPatchOperationOp": ".types",
    "NotFoundError": ".errors",
    "PromptTemplate": ".types",
    "PromptsDeleteResponse": ".prompts",
    "PromptsListResponse": ".prompts",
    "SuccessResponse": ".types",
    "UnauthorizedError": ".errors",
    "prompts": ".prompts",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentChatResponse",
    "AgentChatStreamEvent",
    "AgentChatStreamEventType",
    "AgentCreateRequest",
    "AgentCreateRequestProvider",
    "AgentDeleteResponse",
    "AgentGetChatMessagesRequestOrder",
    "AgentGetChatMessagesRequestRole",
    "AgentGetChatMessagesResponse",
    "AgentListResponse",
    "AgentPromptsResponse",
    "AgentResponse",
    "AgentTemplate",
    "AgentTemplateProvider",
    "BadRequestError",
    "ChatMessageTemplate",
    "ChatMessageTemplateRole",
    "ChatSessionTemplate",
    "ForbiddenError",
    "InternalServerError",
    "JsonPatch",
    "JsonPatchOperation",
    "JsonPatchOperationOp",
    "NotFoundError",
    "PromptTemplate",
    "PromptsDeleteResponse",
    "PromptsListResponse",
    "SuccessResponse",
    "UnauthorizedError",
    "prompts",
]
