# This file was auto-generated by Fern from our API Definition.

import typing

Provider = typing.Union[
    typing.Literal[
        "athenahealth",
        "canvas",
        "cerner",
        "elation",
        "epic",
        "google_healthcare",
        "hapi",
        "medplum",
        "phenostore",
        "sandbox",
    ],
    typing.Any,
]
