# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .create_workflow_request_fhir_provider_id import CreateWorkflowRequestFhirProviderId
    from .create_workflow_response import CreateWorkflowResponse
    from .decision_node_definition import DecisionNodeDefinition
    from .execute_workflow_response import ExecuteWorkflowResponse
    from .execute_workflow_response_results import ExecuteWorkflowResponseResults
    from .lang2fhir_create_definition import Lang2FhirCreateDefinition
    from .lang2fhir_search_definition import Lang2FhirSearchDefinition
    from .list_workflows_response import ListWorkflowsResponse
    from .step_operation import StepOperation
    from .sub_workflow_definition import SubWorkflowDefinition
    from .update_workflow_request_fhir_provider_id import UpdateWorkflowRequestFhirProviderId
    from .workflow_config import WorkflowConfig
    from .workflow_definition import WorkflowDefinition
    from .workflow_graph import WorkflowGraph
    from .workflow_response import WorkflowResponse
    from .workflow_response_graph import WorkflowResponseGraph
    from .workflow_step import WorkflowStep
    from .workflow_step_summary import WorkflowStepSummary
    from .workflow_step_summary_type import WorkflowStepSummaryType
    from .workflow_step_type import WorkflowStepType
    from .workflows_delete_response import WorkflowsDeleteResponse
    from .workflows_get_response import WorkflowsGetResponse
    from .workflows_update_response import WorkflowsUpdateResponse
_dynamic_imports: typing.Dict[str, str] = {
    "CreateWorkflowRequestFhirProviderId": ".create_workflow_request_fhir_provider_id",
    "CreateWorkflowResponse": ".create_workflow_response",
    "DecisionNodeDefinition": ".decision_node_definition",
    "ExecuteWorkflowResponse": ".execute_workflow_response",
    "ExecuteWorkflowResponseResults": ".execute_workflow_response_results",
    "Lang2FhirCreateDefinition": ".lang2fhir_create_definition",
    "Lang2FhirSearchDefinition": ".lang2fhir_search_definition",
    "ListWorkflowsResponse": ".list_workflows_response",
    "StepOperation": ".step_operation",
    "SubWorkflowDefinition": ".sub_workflow_definition",
    "UpdateWorkflowRequestFhirProviderId": ".update_workflow_request_fhir_provider_id",
    "WorkflowConfig": ".workflow_config",
    "WorkflowDefinition": ".workflow_definition",
    "WorkflowGraph": ".workflow_graph",
    "WorkflowResponse": ".workflow_response",
    "WorkflowResponseGraph": ".workflow_response_graph",
    "WorkflowStep": ".workflow_step",
    "WorkflowStepSummary": ".workflow_step_summary",
    "WorkflowStepSummaryType": ".workflow_step_summary_type",
    "WorkflowStepType": ".workflow_step_type",
    "WorkflowsDeleteResponse": ".workflows_delete_response",
    "WorkflowsGetResponse": ".workflows_get_response",
    "WorkflowsUpdateResponse": ".workflows_update_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateWorkflowRequestFhirProviderId",
    "CreateWorkflowResponse",
    "DecisionNodeDefinition",
    "ExecuteWorkflowResponse",
    "ExecuteWorkflowResponseResults",
    "Lang2FhirCreateDefinition",
    "Lang2FhirSearchDefinition",
    "ListWorkflowsResponse",
    "StepOperation",
    "SubWorkflowDefinition",
    "UpdateWorkflowRequestFhirProviderId",
    "WorkflowConfig",
    "WorkflowDefinition",
    "WorkflowGraph",
    "WorkflowResponse",
    "WorkflowResponseGraph",
    "WorkflowStep",
    "WorkflowStepSummary",
    "WorkflowStepSummaryType",
    "WorkflowStepType",
    "WorkflowsDeleteResponse",
    "WorkflowsGetResponse",
    "WorkflowsUpdateResponse",
]
