# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .o_auth_error_error import OAuthErrorError


class OAuthError(UniversalBaseModel):
    """
    OAuth 2.0 error response (RFC 6749 §5.2)
    """

    error: OAuthErrorError = pydantic.Field()
    """
    Error code
    """

    error_description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable error description
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
