# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .role import Role


class OnBehalfOfAuth(UniversalBaseModel):
    client_id: str = pydantic.Field()
    """
    OAuth client ID
    """

    client_secret: str = pydantic.Field()
    """
    OAuth client secret
    """

    role: typing.Optional[Role] = None
    scopes: typing.Optional[str] = pydantic.Field(default=None)
    """
    OAuth scopes to request. Cannot be specified with role. If neither role nor scopes are specified, the provider-specific default role will be used.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
