# This file was auto-generated by Fern from our API Definition.

import typing

OAuthErrorError = typing.Union[
    typing.Literal["invalid_request", "invalid_client", "unsupported_grant_type", "server_error"], typing.Any
]
