# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Citation,
        CodeResponse,
        CodeSystemDetails,
        CodeSystemInfo,
        ConstrueUploadCodeSystemResponse,
        DeleteCodeSystemResponse,
        ExportCodeSystemResponse,
        ExtractCodesResult,
        ExtractRequestConfig,
        ExtractRequestConfigChunkingMethod,
        ExtractRequestConfigValidationMethod,
        ExtractRequestSystem,
        ExtractedCodeResult,
        FeedbackResponse,
        GetCodeResponse,
        GetCodeSystemDetailResponse,
        GetCodeSystemDetailResponseStatus,
        ListCodeSystemsResponse,
        ListCodesResponse,
        SemanticSearchResponse,
        SemanticSearchResult,
        TextSearchResponse,
        TextSearchResult,
        UploadRequestFormat,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        FailedDependencyError,
        ForbiddenError,
        GatewayTimeoutError,
        InternalServerError,
        NotFoundError,
        NotImplementedError,
        ServiceUnavailableError,
        UnauthorizedError,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestError": ".errors",
    "Citation": ".types",
    "CodeResponse": ".types",
    "CodeSystemDetails": ".types",
    "CodeSystemInfo": ".types",
    "ConflictError": ".errors",
    "ConstrueUploadCodeSystemResponse": ".types",
    "DeleteCodeSystemResponse": ".types",
    "ExportCodeSystemResponse": ".types",
    "ExtractCodesResult": ".types",
    "ExtractRequestConfig": ".types",
    "ExtractRequestConfigChunkingMethod": ".types",
    "ExtractRequestConfigValidationMethod": ".types",
    "ExtractRequestSystem": ".types",
    "ExtractedCodeResult": ".types",
    "FailedDependencyError": ".errors",
    "FeedbackResponse": ".types",
    "ForbiddenError": ".errors",
    "GatewayTimeoutError": ".errors",
    "GetCodeResponse": ".types",
    "GetCodeSystemDetailResponse": ".types",
    "GetCodeSystemDetailResponseStatus": ".types",
    "InternalServerError": ".errors",
    "ListCodeSystemsResponse": ".types",
    "ListCodesResponse": ".types",
    "NotFoundError": ".errors",
    "NotImplementedError": ".errors",
    "SemanticSearchResponse": ".types",
    "SemanticSearchResult": ".types",
    "ServiceUnavailableError": ".errors",
    "TextSearchResponse": ".types",
    "TextSearchResult": ".types",
    "UnauthorizedError": ".errors",
    "UploadRequestFormat": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestError",
    "Citation",
    "CodeResponse",
    "CodeSystemDetails",
    "CodeSystemInfo",
    "ConflictError",
    "ConstrueUploadCodeSystemResponse",
    "DeleteCodeSystemResponse",
    "ExportCodeSystemResponse",
    "ExtractCodesResult",
    "ExtractRequestConfig",
    "ExtractRequestConfigChunkingMethod",
    "ExtractRequestConfigValidationMethod",
    "ExtractRequestSystem",
    "ExtractedCodeResult",
    "FailedDependencyError",
    "FeedbackResponse",
    "ForbiddenError",
    "GatewayTimeoutError",
    "GetCodeResponse",
    "GetCodeSystemDetailResponse",
    "GetCodeSystemDetailResponseStatus",
    "InternalServerError",
    "ListCodeSystemsResponse",
    "ListCodesResponse",
    "NotFoundError",
    "NotImplementedError",
    "SemanticSearchResponse",
    "SemanticSearchResult",
    "ServiceUnavailableError",
    "TextSearchResponse",
    "TextSearchResult",
    "UnauthorizedError",
    "UploadRequestFormat",
]
